@@ -63,11 +63,11 @@ class NotificationManagerMock:
     def __init__(self, resource_name: str, logger=None):
         pass
 
-    def stage(self, event_type: str, message, group_id: str, **kwargs):
+    def stage(self, event_type: str, message, **kwargs):
         pass
 
     def flush(self):
         pass
 
-    def publish(self, event_type: str, message, group_id: str, **kwargs):
+    def publish(self, event_type: str, message, **kwargs):
         pass
